@@ -75,16 +75,6 @@ let s: &str = fmt.borrow();
 ## Optional Crate Features
 
 * `serde`: Enables serialization/deserialization support.
-
-
-
-## Installation
-
-Add `utc2k` to your `dependencies` in `Cargo.toml`, like:
-
-```ignore,text
-[dependencies]
-utc2k = "0.3.*"
 ```
 */
 
